@@ -44,6 +44,7 @@ import (
 	minteraws "github.com/openshift/cloud-credential-operator/pkg/aws"
 	"github.com/openshift/cloud-credential-operator/pkg/aws/actuator"
 	mockaws "github.com/openshift/cloud-credential-operator/pkg/aws/mock"
+	"github.com/openshift/cloud-credential-operator/pkg/controller/credentialsrequest/constants"
 	annotatorconst "github.com/openshift/cloud-credential-operator/pkg/controller/secretannotator/constants"
 	"github.com/openshift/cloud-credential-operator/pkg/controller/utils"
 
@@ -739,6 +740,7 @@ func TestCredentialsRequestReconcile(t *testing.T) {
 				testInfrastructure(testInfraName),
 				createTestNamespace(testSecretNamespace),
 				testCredentialsRequestWithRecentLastSync(t),
+				testAWSCredsSecret(testSecretNamespace, testSecretName, testAWSAccessKeyID, testAWSSecretAccessKey),
 			},
 			mockRootAWSClient: func(mockCtrl *gomock.Controller) *mockaws.MockClient {
 				mockAWSClient := mockaws.NewMockClient(mockCtrl)
@@ -749,6 +751,36 @@ func TestCredentialsRequestReconcile(t *testing.T) {
 				assert.Equal(t, testTwentyMinuteOldTimestamp.Unix(), cr.Status.LastSyncTimestamp.Time.Unix())
 			},
 		},
+		{
+			name: "regenerate secret if missing",
+			existing: []runtime.Object{
+				createTestNamespace(testNamespace),
+				testInfrastructure(testInfraName),
+				testClusterVersion(),
+				testAWSCredsSecret("kube-system", "aws-creds", testRootAWSAccessKeyID, testRootAWSSecretAccessKey),
+				createTestNamespace(testSecretNamespace),
+				testCredentialsRequestWithRecentLastSync(t),
+			},
+			mockRootAWSClient: func(mockCtrl *gomock.Controller) *mockaws.MockClient {
+				mockAWSClient := mockaws.NewMockClient(mockCtrl)
+				mockGetUser(mockAWSClient)
+				mockGetUserPolicy(mockAWSClient, testPolicy1)
+				mockListAccessKeys(mockAWSClient, testAWSAccessKeyID)
+				// delete the "old" (now missing secret) access key details
+				mockDeleteAccessKey(mockAWSClient, testAWSAccessKeyID)
+				mockCreateAccessKey(mockAWSClient, testAWSAccessKeyID2, testAWSSecretAccessKey2)
+				return mockAWSClient
+			},
+			validate: func(c client.Client, t *testing.T) {
+				targetSecret := getSecret(c)
+				if assert.NotNil(t, targetSecret) {
+					assert.Equal(t, testAWSAccessKeyID2,
+						string(targetSecret.Data["aws_access_key_id"]))
+					assert.Equal(t, testAWSSecretAccessKey2,
+						string(targetSecret.Data["aws_secret_access_key"]))
+				}
+			},
+		},
 		{
 			name: "recently synced but modified",
 			existing: func() []runtime.Object {
@@ -809,7 +841,7 @@ func TestCredentialsRequestReconcile(t *testing.T) {
 			existing: []runtime.Object{
 				func() runtime.Object {
 					cr := testGCPCredentialsRequest(t)
-					for _, cond := range failureConditionTypes {
+					for _, cond := range constants.FailureConditionTypes {
 						cr.Status.Conditions = append(cr.Status.Conditions, minterv1.CredentialsRequestCondition{
 							Type:   cond,
 							Status: corev1.ConditionTrue,
@@ -875,6 +907,39 @@ func TestCredentialsRequestReconcile(t *testing.T) {
 				assert.NotNil(t, cr.Status.LastSyncTimestamp)
 			},
 		},
+		{
+			name: "new credential but operator disabled",
+			existing: []runtime.Object{
+				createTestNamespace(testNamespace),
+				createTestNamespace(testSecretNamespace),
+				testOperatorConfigMap("true"),
+				testCredentialsRequest(t),
+				testClusterVersion(),
+				testInfrastructure(testInfraName),
+			},
+			mockRootAWSClient: func(mockCtrl *gomock.Controller) *mockaws.MockClient {
+				mockAWSClient := mockaws.NewMockClient(mockCtrl)
+				return mockAWSClient
+			},
+			mockReadAWSClient: func(mockCtrl *gomock.Controller) *mockaws.MockClient {
+				mockAWSClient := mockaws.NewMockClient(mockCtrl)
+				return mockAWSClient
+			},
+			expectedCOConditions: []ExpectedCOCondition{
+				{
+					conditionType: configv1.OperatorAvailable,
+					status:        corev1.ConditionTrue,
+				},
+				{
+					conditionType: configv1.OperatorProgressing,
+					status:        corev1.ConditionFalse,
+				},
+				{
+					conditionType: configv1.OperatorDegraded,
+					status:        corev1.ConditionFalse,
+				},
+			},
+		},
 	}
 
 	for _, test := range tests {
@@ -1328,11 +1393,18 @@ func testInfrastructure(infraName string) *configv1.Infrastructure {
 		Status: configv1.InfrastructureStatus{
 			Platform:           configv1.AWSPlatformType,
 			InfrastructureName: infraName,
-			PlatformStatus: &configv1.PlatformStatus{
-				AWS: &configv1.AWSPlatformStatus{
-					Region: "test-region-2",
-				},
-			},
+		},
+	}
+}
+
+func testOperatorConfigMap(disabled string) *corev1.ConfigMap {
+	return &corev1.ConfigMap{
+		ObjectMeta: metav1.ObjectMeta{
+			Name:      minterv1.CloudCredOperatorConfigMap,
+			Namespace: minterv1.CloudCredOperatorNamespace,
+		},
+		Data: map[string]string{
+			"disabled": disabled,
 		},
 	}
 }
