@@ -3,6 +3,7 @@ package aws
 import (
 	"context"
 	"fmt"
+	"time"
 
 	log "github.com/sirupsen/logrus"
 	"sigs.k8s.io/controller-runtime/pkg/event"
@@ -18,13 +19,16 @@ import (
 	"sigs.k8s.io/controller-runtime/pkg/reconcile"
 	"sigs.k8s.io/controller-runtime/pkg/source"
 
+	minterv1 "github.com/openshift/cloud-credential-operator/pkg/apis/cloudcredential/v1"
 	ccaws "github.com/openshift/cloud-credential-operator/pkg/aws"
+	"github.com/openshift/cloud-credential-operator/pkg/controller/metrics"
 	"github.com/openshift/cloud-credential-operator/pkg/controller/secretannotator/constants"
 	"github.com/openshift/cloud-credential-operator/pkg/controller/utils"
 )
 
 const (
-	// TODO: dynamically detect which environment we're running on
+	controllerName = "secretannotator"
+
 	AWSCloudCredSecretName = "aws-creds"
 
 	AwsAccessKeyName       = "aws_access_key_id"
@@ -83,10 +87,26 @@ type ReconcileCloudCredSecret struct {
 // 3) 'insufficient' for indicating that the creds are not usable for the cluster
 // +kubebuilder:rbac:groups=core,resources=secrets,verbs=get;list;watch;update
 func (r *ReconcileCloudCredSecret) Reconcile(request reconcile.Request) (reconcile.Result, error) {
+	start := time.Now()
+
 	r.Logger.Info("validating cloud cred secret")
 
+	operatorIsDisabled, err := utils.IsOperatorDisabled(r.Client, r.Logger)
+	if err != nil {
+		r.Logger.WithError(err).Error("error checking if operator is disabled")
+		return reconcile.Result{}, err
+	} else if operatorIsDisabled {
+		r.Logger.Infof("operator disabled in %s ConfigMap", minterv1.CloudCredOperatorConfigMap)
+		return reconcile.Result{}, err
+	}
+
+	defer func() {
+		dur := time.Since(start)
+		metrics.MetricControllerReconcileTime.WithLabelValues(controllerName).Observe(dur.Seconds())
+	}()
+
 	secret := &corev1.Secret{}
-	err := r.Get(context.Background(), request.NamespacedName, secret)
+	err = r.Get(context.Background(), request.NamespacedName, secret)
 	if err != nil {
 		r.Logger.Debugf("secret not found: %v", err)
 		return reconcile.Result{}, err
@@ -136,14 +156,7 @@ func (r *ReconcileCloudCredSecret) validateCloudCredsSecret(secret *corev1.Secre
 	}
 
 	// Else, can we just pass through the current creds?
-	region, err := utils.LoadInfrastructureRegion(r.Client, r.Logger)
-	if err != nil {
-		return err
-	}
-	simParams := &ccaws.SimulateParams{
-		Region: region,
-	}
-	cloudCheckResult, err = ccaws.CheckCloudCredPassthrough(awsClient, simParams, r.Logger)
+	cloudCheckResult, err = ccaws.CheckCloudCredPassthrough(awsClient, r.Logger)
 	if err != nil {
 		r.updateSecretAnnotations(secret, constants.InsufficientAnnotation)
 		return fmt.Errorf("failed checking passthrough cloud creds: %v", err)
