@@ -3,8 +3,10 @@ package utils
 import (
 	"context"
 	"fmt"
+	"strconv"
 
 	corev1 "k8s.io/api/core/v1"
+	"k8s.io/apimachinery/pkg/api/errors"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/types"
 	utilrand "k8s.io/apimachinery/pkg/util/rand"
@@ -19,8 +21,9 @@ import (
 )
 
 const (
-	awsCredsSecretIDKey     = "aws_access_key_id"
-	awsCredsSecretAccessKey = "aws_secret_access_key"
+	awsCredsSecretIDKey          = "aws_access_key_id"
+	awsCredsSecretAccessKey      = "aws_secret_access_key"
+	operatorConfigMapDisabledKey = "disabled"
 )
 
 func LoadCredsFromSecret(kubeClient client.Client, namespace, secretName string) ([]byte, []byte, error) {
@@ -51,37 +54,16 @@ func LoadCredsFromSecret(kubeClient client.Client, namespace, secretName string)
 // LoadInfrastructureName loads the cluster Infrastructure config and returns the infra name
 // used to identify this cluster, and tag some cloud objects.
 func LoadInfrastructureName(c client.Client, logger log.FieldLogger) (string, error) {
-	infra, err := getInfrastructure(c)
+	infra := &configv1.Infrastructure{}
+	err := c.Get(context.Background(), types.NamespacedName{Name: "cluster"}, infra)
 	if err != nil {
 		logger.WithError(err).Error("error loading Infrastructure config 'cluster'")
 		return "", err
 	}
-	logger.Debugf("Loading infrastructure name: %s", infra.Status.InfrastructureName)
+
+	logger.Debugf("Loaded infrastructure name: %s", infra.Status.InfrastructureName)
 	return infra.Status.InfrastructureName, nil
-}
 
-// LoadInfrastructureRegion loads the AWS region the cluster is installed to.
-func LoadInfrastructureRegion(c client.Client, logger log.FieldLogger) (string, error) {
-	infra, err := getInfrastructure(c)
-	if err != nil {
-		logger.WithError(err).Error("error loading Infrastructure region")
-		return "", err
-	}
-	if infra.Status.PlatformStatus == nil {
-		// Older clusters may have an Infrastructure object without the PlatformStatus fields.
-		// Send back an empty region and the AWS client will use default settings.
-		// The permissions simulation will also simply not fill out the region for simulations.
-		return "", nil
-	}
-	return infra.Status.PlatformStatus.AWS.Region, nil
-}
-
-func getInfrastructure(c client.Client) (*configv1.Infrastructure, error) {
-	infra := &configv1.Infrastructure{}
-	if err := c.Get(context.TODO(), types.NamespacedName{Name: "cluster"}, infra); err != nil {
-		return nil, err
-	}
-	return infra, nil
 }
 
 // GetCredentialsRequestCloudType decodes a Spec.ProviderSpec and returns the kind
@@ -134,3 +116,30 @@ func GenerateNameWithFieldLimits(infraName string, infraNameMaxLen int, crName s
 	}
 	return fmt.Sprintf("%s%s", infraPrefix, crName), nil
 }
+
+// IsOperatorDisabled checks the cloud-credential-operator-config ConfigMap for a
+// "disabled" property set to true. If the configmap or property do not exist, we assume
+// false and continue normal operation. This should be used in all controllers to shutdown
+// functionality in environments where admins want to manage their credentials themselves.
+func IsOperatorDisabled(kubeClient client.Client, logger log.FieldLogger) (bool, error) {
+	cm := &corev1.ConfigMap{}
+	err := kubeClient.Get(context.TODO(),
+		types.NamespacedName{
+			Namespace: minterv1.CloudCredOperatorNamespace,
+			Name:      minterv1.CloudCredOperatorConfigMap,
+		}, cm)
+	if err != nil {
+		if errors.IsNotFound(err) {
+			logger.Debugf("%s ConfigMap does not exist, assuming default behavior", minterv1.CloudCredOperatorConfigMap)
+			return false, nil
+		}
+		return false, err
+	}
+
+	disabled, ok := cm.Data[operatorConfigMapDisabledKey]
+	if !ok {
+		logger.Debugf("%s ConfigMap has no %s key, assuming default behavior", minterv1.CloudCredOperatorConfigMap, operatorConfigMapDisabledKey)
+		return false, nil
+	}
+	return strconv.ParseBool(disabled)
+}
